@@ -77,6 +77,9 @@ class SingularityClient(ContainerClient):
         compose = self.config.compose
         compose["instances"] = compose.pop("services")
         for service in compose["instances"].values():
+            tmpdir = tempfile.TemporaryDirectory(dir=Path(".").resolve())
+            self._tmpdirs.append(tmpdir)
+
             # Replicate docker and don't share home
             start = {"options": ["no-home"]}
             service["start"] = ATKConfig._merge_dictionaries(start, service.get("start", {}))
@@ -90,10 +93,10 @@ class SingularityClient(ContainerClient):
 
             if "build" in service:
                 build = service["build"]
-
-                tmpdir = tempfile.TemporaryDirectory(dir=Path(".").resolve())
-                build["options"] = [f"tmpdir={tmpdir.name}", "fakeroot"]
-                self._tmpdirs.append(tmpdir)
+                build["options"] = []
+                build["options"].append("fakeroot")
+                build["options"].append("fix-perms")
+                build["options"].append(f"tmpdir={tmpdir.name}")
 
                 # The name for the build definition in singularity compose is "recipe", not "dockerfile"
                 if "dockerfile" in build:
@@ -123,7 +126,9 @@ class SingularityClient(ContainerClient):
         Returns:
             bool: Whether the command succeeded.
         """
-        return super().up("--no-resolv")
+        if "--resolv" not in args:
+            args = [*args, "--no-resolv"]
+        return super().up(*args)
 
     def run(self, service, *exec_cmd) -> bool:
         """Run a command in a container.
